import API from '@API/index';
import Env from '@Env/index';
import { postGlobalReduxReset } from '@Reducers/global/actions';
import { errorCatch } from './errorCapture';

const EXPIRE_TIME_MS = 1000 * 60 * 60 * 24; // 確認一天前有沒有過期

/* General Action : For Local Token Storage */
export const removeLocalUserToken = (env: Env): void => {
  const localTokenName = env.TokenLocalStorageName;
  const localToken = localStorage.getItem(localTokenName);
  if (localToken) {
    localStorage.removeItem(localTokenName);
  }
};
export const saveLocalUserToken = (env: Env, token: string): void => {
  const localTokenName = env.TokenLocalStorageName;
  const localToken = localStorage.getItem(localTokenName);
  if (localToken) {
    removeLocalUserToken(env);
  }
  localStorage.setItem(localTokenName, JSON.stringify({ token }));
};
export const readLocalUserToken = async (env: Env, api: API): Promise<boolean> => {
  const localTokenName = env.TokenLocalStorageName;
  const localToken = localStorage.getItem(localTokenName);
  if (localToken) {
    const localTokenJson = JSON.parse(localToken);
    api.updateAccessToken(localTokenJson.token);
    const isAccessExpired = await api.checkAccessTokenExpired(EXPIRE_TIME_MS);
    if (isAccessExpired) {
      removeLocalUserToken(env);
      return false;
    }
    const result = await api.user.postUserRefreshToken();
    if (!result.error) {
      api.updateAccessToken(result.token);
      localStorage.setItem(localTokenName, JSON.stringify({ token: result.token }));
      return true;
    }
    if (result.error) {
      api.removeAccessToken();
      return false;
    }
  }
  return false;
};
export const checkUserTokenIsValid = async (env: Env, api: API, dispatch: any): Promise<boolean> => {
  const isAccessTokenValid = await api.checkAccessTokenValid(); // 確認 Token 是否合法
  /* 合法 */
  if (isAccessTokenValid) {
    const isAccessTokenExpired = await api.checkAccessTokenExpired(EXPIRE_TIME_MS); // 確認 Token 是否過期
    /* 沒過期 */
    if (!isAccessTokenExpired) {
      return true;
    }
    /* 過期 */
    if (isAccessTokenExpired) {
      const result = await api.user.postUserRefreshToken(); // 嘗試更新 Token
      /* 更新成功, 更換 API Token */
      if (!result.error) {
        const localTokenName = env.TokenLocalStorageName;
        const localToken = localStorage.getItem(localTokenName);
        if (localToken) {
          api.removeAccessToken();
          localStorage.removeItem(localTokenName);
        }
        localStorage.setItem(localTokenName, JSON.stringify({ token: result.token }));
        api.updateAccessToken(result.token);
        return true;
      }
      /* 更新失敗, 清空所有狀態, 讓使用者重新登入 */
      if (result.error) {
        api.removeAccessToken();
        dispatch(postGlobalReduxReset());
        dispatch(errorCatch(result.error));
        return false;
      }
    }
    return true;
  }
  /* 不合法 */
  if (!isAccessTokenValid) {
    const localTokenName = env.TokenLocalStorageName;
    localStorage.removeItem(localTokenName);
    api.removeAccessToken();
    dispatch(postGlobalReduxReset());
    return false;
  }
  return false;
};
